#!/bin/sh
# 2010-08-17
#
if [ ! -x bin/net ]
then
   exit 1
fi
mv /usr/bin/net   /usr/bin/net.org
mv bin/net /usr/bin/
mv /usr/sbin/smbd /usr/bin/smbd.org
mv bin/smbd /usr/sbin
mv bin/mgrshare   /usr/local/sbin
mv bin/crackcheck /usr/local/sbin
chkconfig apache2 on
chkconfig smb on
chkconfig nmb on
chkconfig winbind on
chkconfig ldap on

